# Generated by roxygen2: do not edit by hand

export("%>%")
export(":=")
export(.data)
export(as_label)
export(as_name)
export(bootstrap_density_augment)
export(bootstrap_p_augment)
export(bootstrap_p_vec)
export(bootstrap_q_augment)
export(bootstrap_q_vec)
export(bootstrap_stat_plot)
export(bootstrap_unnest_tbl)
export(cgmean)
export(check_duplicate_rows)
export(chmean)
export(ci_hi)
export(ci_lo)
export(ckurtosis)
export(cmean)
export(cmedian)
export(color_blind)
export(convert_to_ts)
export(csd)
export(cskewness)
export(cvar)
export(dist_type_extractor)
export(enquo)
export(enquos)
export(quantile_normalize)
export(td_scale_color_colorblind)
export(td_scale_fill_colorblind)
export(tidy_autoplot)
export(tidy_bernoulli)
export(tidy_beta)
export(tidy_binomial)
export(tidy_bootstrap)
export(tidy_burr)
export(tidy_cauchy)
export(tidy_chisquare)
export(tidy_combine_distributions)
export(tidy_combined_autoplot)
export(tidy_distribution_comparison)
export(tidy_distribution_summary_tbl)
export(tidy_empirical)
export(tidy_exponential)
export(tidy_f)
export(tidy_four_autoplot)
export(tidy_gamma)
export(tidy_generalized_beta)
export(tidy_generalized_pareto)
export(tidy_geometric)
export(tidy_hypergeometric)
export(tidy_inverse_burr)
export(tidy_inverse_exponential)
export(tidy_inverse_gamma)
export(tidy_inverse_normal)
export(tidy_inverse_pareto)
export(tidy_inverse_weibull)
export(tidy_kurtosis_vec)
export(tidy_logistic)
export(tidy_lognormal)
export(tidy_mcmc_sampling)
export(tidy_mixture_density)
export(tidy_multi_dist_autoplot)
export(tidy_multi_single_dist)
export(tidy_negative_binomial)
export(tidy_normal)
export(tidy_paralogistic)
export(tidy_pareto)
export(tidy_pareto1)
export(tidy_poisson)
export(tidy_random_walk)
export(tidy_random_walk_autoplot)
export(tidy_range_statistic)
export(tidy_scale_zero_one_vec)
export(tidy_skewness_vec)
export(tidy_stat_tbl)
export(tidy_t)
export(tidy_triangular)
export(tidy_uniform)
export(tidy_weibull)
export(tidy_zero_truncated_binomial)
export(tidy_zero_truncated_geometric)
export(tidy_zero_truncated_negative_binomial)
export(tidy_zero_truncated_poisson)
export(triangle_plot)
export(util_bernoulli_param_estimate)
export(util_bernoulli_stats_tbl)
export(util_beta_aic)
export(util_beta_param_estimate)
export(util_beta_stats_tbl)
export(util_binomial_aic)
export(util_binomial_param_estimate)
export(util_binomial_stats_tbl)
export(util_burr_param_estimate)
export(util_burr_stats_tbl)
export(util_cauchy_aic)
export(util_cauchy_param_estimate)
export(util_cauchy_stats_tbl)
export(util_chisq_aic)
export(util_chisquare_param_estimate)
export(util_chisquare_stats_tbl)
export(util_exponential_aic)
export(util_exponential_param_estimate)
export(util_exponential_stats_tbl)
export(util_f_aic)
export(util_f_param_estimate)
export(util_f_stats_tbl)
export(util_gamma_aic)
export(util_gamma_param_estimate)
export(util_gamma_stats_tbl)
export(util_generalized_beta_aic)
export(util_generalized_beta_param_estimate)
export(util_generalized_beta_stats_tbl)
export(util_generalized_pareto_aic)
export(util_generalized_pareto_param_estimate)
export(util_generalized_pareto_stats_tbl)
export(util_geometric_aic)
export(util_geometric_param_estimate)
export(util_geometric_stats_tbl)
export(util_hypergeometric_aic)
export(util_hypergeometric_param_estimate)
export(util_hypergeometric_stats_tbl)
export(util_inverse_burr_aic)
export(util_inverse_burr_param_estimate)
export(util_inverse_burr_stats_tbl)
export(util_inverse_pareto_aic)
export(util_inverse_pareto_param_estimate)
export(util_inverse_pareto_stats_tbl)
export(util_inverse_weibull_aic)
export(util_inverse_weibull_param_estimate)
export(util_inverse_weibull_stats_tbl)
export(util_logistic_aic)
export(util_logistic_param_estimate)
export(util_logistic_stats_tbl)
export(util_lognormal_aic)
export(util_lognormal_param_estimate)
export(util_lognormal_stats_tbl)
export(util_negative_binomial_aic)
export(util_negative_binomial_param_estimate)
export(util_negative_binomial_stats_tbl)
export(util_normal_aic)
export(util_normal_param_estimate)
export(util_normal_stats_tbl)
export(util_paralogistic_aic)
export(util_paralogistic_param_estimate)
export(util_paralogistic_stats_tbl)
export(util_pareto1_aic)
export(util_pareto1_param_estimate)
export(util_pareto1_stats_tbl)
export(util_pareto_aic)
export(util_pareto_param_estimate)
export(util_pareto_stats_tbl)
export(util_poisson_aic)
export(util_poisson_param_estimate)
export(util_poisson_stats_tbl)
export(util_t_aic)
export(util_t_param_estimate)
export(util_t_stats_tbl)
export(util_triangular_aic)
export(util_triangular_param_estimate)
export(util_triangular_stats_tbl)
export(util_uniform_aic)
export(util_uniform_param_estimate)
export(util_uniform_stats_tbl)
export(util_weibull_aic)
export(util_weibull_param_estimate)
export(util_weibull_stats_tbl)
export(util_zero_truncated_binomial_aic)
export(util_zero_truncated_binomial_param_estimate)
export(util_zero_truncated_binomial_stats_tbl)
export(util_zero_truncated_geometric_aic)
export(util_zero_truncated_geometric_param_estimate)
export(util_zero_truncated_geometric_stats_tbl)
export(util_zero_truncated_negative_binomial_aic)
export(util_zero_truncated_negative_binomial_param_estimate)
export(util_zero_truncated_negative_binomial_stats_tbl)
export(util_zero_truncated_poisson_aic)
export(util_zero_truncated_poisson_param_estimate)
export(util_zero_truncated_poisson_stats_tbl)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,melt)
importFrom(magrittr,"%>%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
